@@ -11,9 +11,9 @@ use Getopt::Long qw<:config auto_help bundling>;
 use Pod::Find qw<pod_where>;
 use Pod::Usage;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 my ($dry_run, $source, $dest, $recursive, $force, @add_ignore);
-my $ignore = '^\.(?:git|svn)(?:/.*)?$';
+my $ignore = '(?:.*/)?.(?:git|svn)(?:/.*)?$';
 
 sub run {
     GetOptions(
